@@ -20,7 +20,7 @@ class ProperlyEvents(str, Enum):
     FAVOURITE_ADDED = 'favouriteAdded'
     FAVOURITE_REMOVED = 'favouriteRemoved'
     USER_DEAL_STAGES_CHANGED = 'userDealStagesChanged'
-    BEHAVIOUR_TRACK_EVENT = 'behaviourTrackEvent_gcL38BxP60q07RV4B2C3Cg'
+    BEHAVIOUR_TRACK_EVENT = 'behaviourTrackEvent'
 
 
 class EventBusBase:
